@@ -2,16 +2,7 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "шуудан",
-    "Inbox" : "ирсэн",
-    "Sent" : "илгээсэн",
-    "Drafts" : "ноорог",
-    "Archive" : "архив",
-    "Trash" : "хог",
-    "Junk" : "хэрэггүй",
-    "All" : "бүх",
-    "Favorites" : "дуртай",
     "Creating account failed: " : "аккаунт үүсгэж чадсангүй:",
-    "Delete permanently" : "бүр мөсөн устгах",
     "Name" : "нэр",
     "Mail Address" : "шуудангийн хаяг",
     "Password" : "нууц үг",
@@ -25,7 +16,6 @@ OC.L10N.register(
     "SMTP Password" : "Энгийн мэйл дамжуулах протокол-ийн нууц үг",
     "Connect" : "холбох",
     "Add mail account" : "шуудангийн хаяг нэмэх",
-    "from" : "тэндээс",
     "Subject" : "Сэдэв",
     "Sending …" : "илгээмж",
     "Message sent!" : "зурвас илгээсэн",
