@@ -11,8 +11,6 @@ OC.L10N.register(
     "Subject" : "Assunto",
     "Saving draft …" : "A guardar rascunho ...",
     "Draft saved" : "Rascunho guardado",
-    "Message options" : "Opções da mensagem",
-    "Plain text" : "Texto simples",
     "Uploading attachments …" : "A enviar anexos ...",
     "Sending …" : "A enviar...",
     "Go back" : "Voltar",
@@ -20,6 +18,7 @@ OC.L10N.register(
     "Reply sent!" : "Resposta enviada!",
     "Send" : "Enviar",
     "Choose a file to add as attachment" : "Escolha um ficheiro para adicionar como anexo",
+    "Plain text" : "Texto simples",
     "Draft: " : "Rascunho:",
     "Mark read" : "Marcar como lido",
     "Mark unread" : "Marcar como não lido",
@@ -37,7 +36,6 @@ OC.L10N.register(
     "Collapse folders" : "Ocultar pastas",
     "Mark all as read" : "Marcar todas como lidas",
     "{from}\n{subject}" : "{from}\n{subject}",
-    "All inboxes" : "Todas as caixas de entrada",
     "Error loading message" : "Erro ao carregar a mensagem",
     "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se não for automaticamente redireccionado dentro de segundos.",
     "Redirect" : "Redirecionar",
