@@ -1,7 +1,7 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Pošta ·",
+    "Mail" : "Pošta",
     "Auto detect failed. Please use manual mode." : "Samodejno zaznavanje je spodletelo. Zaznavo bo treba izvesti ročno.",
     "Updating account failed: " : "Posodobitev računa je spodletela:",
     "Creating account failed: " : "Ustvarjanje računa je spodletelo:",
@@ -32,9 +32,22 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Uporabi podobe Gravatar in Favicon",
     "Keyboard shortcuts" : "Tipkovne bližnjice",
     "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Ali iščete rešitev za šifriranje sporočil elektronske pošte? Namestite razširitev za brskalnik Mailvelope!",
+    "From" : "Od",
+    "Select account" : "Izbor računa",
+    "To" : "Za",
+    "Contact or email address …" : "Stik ali elektronski naslov ...",
+    "+ Copy" : "+ Kopiraj",
+    "Copy" : "Kopiraj",
+    "No contacts found." : "Ni najdenih stikov.",
+    "Blind copy" : "Skrita kopija",
     "Subject" : "Zadeva",
+    "Subject …" : "Zadeva ...",
+    "This message came from a noreply address so your reply will probably not be read." : "Sporočilo je bilo poslano z naslova, ki ni namenjen odgovarjanju, zato odgovor najverjetneje ne bo prispel do naslovnika.",
+    "Write message …" : "Besedilo sporočila ...",
     "Saving draft …" : "Poteka shranjevanje osnutka ...",
     "Draft saved" : "Osnutek je shranjen",
+    "Upload attachment" : "Pošlji prilogo",
+    "Add attachment from Files" : "Dodaj prilogo iz Datotek",
     "Uploading attachments …" : "Poteka pošiljanje prilog ...",
     "Sending …" : "Poteka pošiljanje ...",
     "Error sending your message" : "Prošlo je do napake med pošiljanjem sporočila",
@@ -45,14 +58,17 @@ OC.L10N.register(
     "Write another message" : "Sestavite novo sporočilo",
     "Send" : "Pošlji",
     "Uploading {percent}% …" : "Poteka nalaganje {percent}% …",
-    "Upload attachment" : "Pošlji prilogo",
-    "Add attachment from Files" : "Dodaj prilogo iz Datotek",
     "Choose a file to add as attachment" : "Izbor datoteke za prilogo",
+    "Writing mode" : "Način pisanja",
+    "Preferred writing mode for new messages and replies." : "Prednostni način pisanja sporočil za nova sporočila in odgovore.",
+    "Plain text" : "Besedilno",
+    "Rich text" : "Obogateno besedilo",
     "No messages in this folder" : "V tej mapi ni sporočil",
     "Draft: " : "Osnutek:",
     "Mark read" : "Označi kot prebrano",
     "Mark unread" : "Označi kot neprebrano",
     "Delete" : "Izbriši",
+    "Blind copy recipients only" : "Le prejemniki skrite kopije",
     "Report this bug" : "Pošlji poročilo o hrošču",
     "Loading messages" : "Nalaganje sporočil",
     "Not found" : "Ni mogoče najti",
@@ -70,16 +86,28 @@ OC.L10N.register(
     "Show images from this\tsender" : "Pokaži slike od tega \tpošiljatelja",
     "New message" : "Novo sporočilo",
     "Settings" : "Nastavitve",
+    "Edit account" : "Uredi račun",
+    "Delete account" : "Izbriši račun",
     "Add folder" : "Dodaj mapo",
     "Show all folders" : "Pokaži vse mape",
     "Collapse folders" : "Zloži mape",
     "Mark all as read" : "Označi vse kot prebrano",
+    "Mark all messages of this folder as read" : "Označi vsa sporočila v tej mapi kot prebrana",
     "Add subfolder" : "Dodaj podmapo",
+    "{total} messages" : "{total} sporočil",
+    "{unread} unread of {total}" : "{unread} neprebranih od skupno {total}",
+    "Loading …" : "Poteka nalaganje …",
     "Could not load your draft" : "Osnutka ni mogoče naložiti",
+    "Could not load original message" : "Ni mogoče naložiti izvornega sporočila",
     "No message selected" : "Ni izbranega nobenega sporočila",
     "Signature" : "Podpis",
+    "A signature is added to the text of new messages and replies." : "K besedilu novih sporočil in odgovorov je dodan podpis.",
+    "Signature …" : "Podpis ...",
+    "Save signature" : "Shrani podpis",
+    "Account settings" : "Nastavitve računa",
+    "Change name" : "Spremeni ime",
     "Mail server" : "Poštni strežnik",
-    "Speed up your Mail experience with these quick shortcuts." : "Pospešite svojo izkušnjo s Pošto s temi hitrimi bližnjicami.",
+    "Speed up your Mail experience with these quick shortcuts." : "Pospešite delo s Pošto z uporabo tipkovnih bližnjic.",
     "Compose new message" : "Novo sporočilo",
     "Newer message" : "Novejše sporočilo",
     "Older message" : "Starejše sporočilo",
@@ -88,20 +116,20 @@ OC.L10N.register(
     "Search" : "Iskanje",
     "Refresh" : "Osveži",
     "Connect your mail account" : "Povežite svoj elektronski račun",
+    "Unexpected error during account creation" : "Prišlo je do nepričakovane napake med ustvarjanjem računa",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n novo sporočilo \npošilja {from}","%n novi sporočili \npošilja {from}","%n nova sporočila \npošilja {from}","%n novih sporočil \npošilja {from}"],
     "Nextcloud Mail" : "Pošta Nextcloud Mail",
-    "All inboxes" : "Vsi predali",
     "Could not load {tag}{name}{endtag}" : "Ni mogoče naložiti {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Napaka pri nalaganju {tag}{name}{endtag}",
-    "Could not load the desired message" : "Ne morem naložiti želenega sporočila",
-    "Could not load the message" : "Ne morem naložiti sporočila",
+    "There was a problem loading {tag}{name}{endtag}" : "Prišlo je do napake pri nalaganju {tag}{name}{endtag}",
+    "Could not load the desired message" : "Želenega sporočila ni mogoče naložiti",
+    "Could not load the message" : "Sporočila ni mogoče naložiti",
     "Error loading message" : "Napaka nalaganja sporočila",
-    "Forwarding to %s" : "Posredujem na %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Pritisnite tukaj če ne boste samodejno preusmerjeni v roku nekaj sekund.",
+    "Forwarding to %s" : "Poteka posredovanje sporočila za %s",
+    "Click here if you are not automatically redirected within the next few seconds." : "Če vas sistem v nekaj sekundah ne preusmeri samodejno, pritisnite na to mesto.",
     "Redirect" : "Preusmeri",
-    "The link leads to %s" : "Povezava vodi na %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Če ne želite obiskati te strani, se lahko vrnete na <a href=\"%s\">pošto</a>.",
+    "The link leads to %s" : "Povezava vodi do %s",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Če ne želite obiskati te strani, se lahko vrnete v <a href=\"%s\">poštni nabiralnik</a>.",
     "Continue to %s" : "Nadaljuj na %s"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
