@@ -29,7 +29,17 @@ use OCA\Mail\Contracts\IAvatarService;
 use OCA\Mail\Contracts\IMailManager;
 use OCA\Mail\Contracts\IMailTransmission;
 use OCA\Mail\Contracts\IUserPreferences;
+use OCA\Mail\Events\BeforeMessageDeletedEvent;
+use OCA\Mail\Events\DraftSavedEvent;
+use OCA\Mail\Events\MessageSentEvent;
+use OCA\Mail\Events\SaveDraftEvent;
 use OCA\Mail\Http\Middleware\ErrorMiddleware;
+use OCA\Mail\Listener\AddressCollectionListener;
+use OCA\Mail\Listener\DeleteDraftListener;
+use OCA\Mail\Listener\DraftMailboxCreatorListener;
+use OCA\Mail\Listener\FlagRepliedMessageListener;
+use OCA\Mail\Listener\TrashMailboxCreatorListener;
+use OCA\Mail\Listener\SaveSentMessageListener;
 use OCA\Mail\Service\Attachment\AttachmentService;
 use OCA\Mail\Service\AvatarService;
 use OCA\Mail\Service\Group\IGroupService;
@@ -38,44 +48,17 @@ use OCA\Mail\Service\MailManager;
 use OCA\Mail\Service\MailTransmission;
 use OCA\Mail\Service\UserPreferenceSevice;
 use OCP\AppFramework\App;
+use OCP\EventDispatcher\IEventDispatcher;
 use OCP\Util;
 
 class Application extends App {
 
+	public const APP_ID = 'mail';
+
 	public function __construct(array $urlParams = []) {
-		parent::__construct('mail', $urlParams);
+		parent::__construct(self::APP_ID, $urlParams);
 
-		$this->initializeAppContainer();
-	}
-
-	private function initializeAppContainer() {
-		$container = $this->getContainer();
-
-		$transport = $container->getServer()->getConfig()->getSystemValue('app.mail.transport', 'smtp');
-		$testSmtp = $transport === 'smtp';
-
-		$container->registerAlias(IAvatarService::class, AvatarService::class);
-		$container->registerAlias(IAttachmentService::class, AttachmentService::class);
-		$container->registerAlias(IMailManager::class, MailManager::class);
-		$container->registerAlias(IMailTransmission::class, MailTransmission::class);
-		$container->registerAlias(IUserPreferences::class, UserPreferenceSevice::class);
-		$container->registerService('OCP\ISession', function ($c) {
-			return $c->getServer()->getSession();
-		});
-
-		$container->registerParameter("appName", "mail");
-		$container->registerService("userFolder", function () use ($container) {
-			$user = $container->query("UserId");
-			return $container->getServer()->getUserFolder($user);
-		});
-
-		$container->registerParameter("testSmtp", $testSmtp);
-		$container->registerParameter("hostname", Util::getServerHostName());
-
-		$container->registerAlias('ErrorMiddleware', ErrorMiddleware::class);
-		$container->registerMiddleWare('ErrorMiddleware');
-
-		$container->registerAlias(IGroupService::class, NextcloudGroupService::class);
+		BootstrapSingleton::getInstance($this->getContainer())->boot();
 	}
 
 }
