@@ -61,6 +61,8 @@ use OCP\AppFramework\Db\Entity;
  * @method void setSignature(string|null $signature)
  * @method int getLastMailboxSync()
  * @method void setLastMailboxSync(int $time)
+ * @method string getEditorMode()
+ * @method void setEditorMode(string $editorMode)
  */
 class MailAccount extends Entity {
 
@@ -79,6 +81,7 @@ class MailAccount extends Entity {
 	protected $outboundPassword;
 	protected $signature;
 	protected $lastMailboxSync;
+	protected $editorMode;
 
 	/**
 	 * @param array $params
@@ -143,6 +146,7 @@ class MailAccount extends Entity {
 			'imapUser' => $this->getInboundUser(),
 			'imapSslMode' => $this->getInboundSslMode(),
 			'signature' => $this->getSignature(),
+			'editorMode' => $this->getEditorMode(),
 		];
 
 		if (!is_null($this->getOutboundHost())) {
