@@ -47,9 +47,6 @@ class Folder implements JsonSerializable {
 	/** @var string[] */
 	private $specialUse;
 
-	/** @var string */
-	private $displayName;
-
 	/** @var string */
 	private $syncToken;
 
@@ -67,7 +64,6 @@ class Folder implements JsonSerializable {
 		$this->folders = [];
 		$this->status = [];
 		$this->specialUse = [];
-		$this->displayName = '';
 	}
 
 	/**
@@ -119,20 +115,6 @@ class Folder implements JsonSerializable {
 		return $this->specialUse;
 	}
 
-	/**
-	 * @return string
-	 */
-	public function getDisplayName() {
-		return $this->displayName;
-	}
-
-	/**
-	 * @param string $displayName
-	 */
-	public function setDisplayName($displayName) {
-		$this->displayName = $displayName;
-	}
-
 	/**
 	 * @return Folder[]
 	 */
@@ -169,7 +151,7 @@ class Folder implements JsonSerializable {
 		return [
 			'id' => base64_encode($this->getMailbox()),
 			'accountId' => $this->accountId,
-			'name' => $this->getDisplayName(),
+			'displayName' => $this->getMailbox(),
 			'unseen' => isset($this->status['unseen']) ? $this->status['unseen'] : 0,
 			'total' => isset($this->status['messages']) ? (int) $this->status['messages'] : 0,
 			'isEmpty' => isset($this->status['messages']) ? 0 >= (int) $this->status['messages'] : true,
