@@ -60,22 +60,20 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 */
 	private $attachmentsToIgnore = ['signature.asc', 'smime.p7s'];
 
-	/** @var int */
-	private $uid;
-
 	/** @var Html|null */
 	private $htmlService;
 
 	/**
 	 * @param Horde_Imap_Client_Socket|null $conn
-	 * @param Horde_Imap_Client_Mailbox $mailBox
+	 * @param Horde_Imap_Client_Mailbox|string $mailBox
 	 * @param int $messageId
 	 * @param Horde_Imap_Client_Data_Fetch|null $fetch
 	 * @param bool $loadHtmlMessage
 	 * @param Html|null $htmlService
 	 * @throws DoesNotExistException
 	 */
-	public function __construct($conn, $mailBox,
+	public function __construct($conn,
+								$mailBox,
 								int $messageId,
 								Horde_Imap_Client_Data_Fetch $fetch = null,
 								bool $loadHtmlMessage = false,
@@ -127,20 +125,9 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 * @return int
 	 */
 	public function getUid(): int {
-		if (!is_null($this->uid)) {
-			return $this->uid;
-		}
 		return $this->fetch->getUid();
 	}
 
-	public function setUid(int $uid) {
-		$this->uid = $uid;
-		$this->attachments = array_map(function ($attachment) use ($uid) {
-			$attachment['messageId'] = $uid;
-			return $attachment;
-		}, $this->attachments);
-	}
-
 	/**
 	 * @return array
 	 */
@@ -236,19 +223,17 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	/**
 	 * Get the ID if available
 	 *
-	 * @return int|null
+	 * @return string
 	 */
-	public function getMessageId() {
-		$e = $this->getEnvelope();
-		return $e->message_id;
+	public function getMessageId(): string {
+		return $this->getEnvelope()->message_id;
 	}
 
 	/**
 	 * @return string
 	 */
 	public function getSubject(): string {
-		$e = $this->getEnvelope();
-		return $e->subject;
+		return $this->getEnvelope()->subject;
 	}
 
 	/**
@@ -304,8 +289,6 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	}
 
 	private function loadMessageBodies() {
-		$headers = [];
-
 		$fetch_query = new Horde_Imap_Client_Fetch_Query();
 		$fetch_query->envelope();
 		$fetch_query->structure();
@@ -313,18 +296,6 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		$fetch_query->size();
 		$fetch_query->imapDate();
 
-		$headers = array_merge($headers, [
-			'importance',
-			'list-post',
-			'x-priority'
-		]);
-		$headers[] = 'content-type';
-
-		$fetch_query->headers('imp', $headers, [
-			'cache' => true,
-			'peek' => true
-		]);
-
 		// $list is an array of Horde_Imap_Client_Data_Fetch objects.
 		$ids = new Horde_Imap_Client_Ids($this->messageId);
 		$headers = $this->conn->fetch($this->mailBox, $fetch_query, ['ids' => $ids]);
@@ -414,19 +385,19 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	}
 
 	/**
-	 * @param string $specialRole
 	 * @return array
 	 */
-	public function getFullMessage($specialRole = null): array {
+	public function getFullMessage(int $accountId, string $mailbox, int $id): array {
 		$mailBody = $this->plainMessage;
 
 		$data = $this->jsonSerialize();
 		if ($this->hasHtmlMessage) {
 			$data['hasHtmlBody'] = true;
+			$data['body'] = $this->getHtmlBody($accountId, $mailbox, $id);
 		} else {
 			$mailBody = $this->htmlService->convertLinks($mailBody);
 			list($mailBody, $signature) = $this->htmlService->parseMailBody($mailBody);
-			$data['body'] = $specialRole === 'drafts' ? $mailBody : nl2br($mailBody);
+			$data['body'] = $mailBody;
 			$data['signature'] = $signature;
 		}
 
@@ -445,12 +416,8 @@ class IMAPMessage implements IMessage, JsonSerializable {
 			'to' => $this->getTo()->jsonSerialize(),
 			'cc' => $this->getCC()->jsonSerialize(),
 			'bcc' => $this->getBCC()->jsonSerialize(),
-			'fromEmail' => is_null($this->getFrom()->first()) ? null : $this->getFrom()->first()->getEmail(),
 			'subject' => $this->getSubject(),
-			'date' => OC::$server->getDateTimeFormatter()->formatDate($this->getSentDate()->format('U')),
 			'dateInt' => $this->getSentDate()->getTimestamp(),
-			'dateIso' => $this->getSentDate()->format('c'),
-			'size' => Util::humanFileSize($this->getSize()),
 			'flags' => $this->getFlags(),
 		];
 	}
@@ -459,15 +426,24 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 * @param int $accountId
 	 * @param string $folderId
 	 * @param int $messageId
-	 * @param Closure $attachments
 	 * @return string
 	 */
-	public function getHtmlBody(int $accountId, string $folderId, int $messageId, Closure $attachments): string {
+	public function getHtmlBody(int $accountId, string $folderId, int $messageId): string {
 		return $this->htmlService->sanitizeHtmlMailBody($this->htmlMessage, [
 			'accountId' => $accountId,
 			'folderId' => $folderId,
 			'messageId' => $messageId,
-		], $attachments);
+		], function ($cid) {
+			$match = array_filter($this->attachments,
+				function ($a) use ($cid) {
+					return $a['cid'] === $cid;
+				});
+			$match = array_shift($match);
+			if ($match === null) {
+				return null;
+			}
+			return $match['id'];
+		});
 	}
 
 	/**
@@ -594,14 +570,14 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	/**
 	 * @return IMessage|null
 	 */
-	public function getRepliedMessage() {
+	public function getInReplyTo() {
 		throw new Exception('not implemented');
 	}
 
 	/**
 	 * @param IMessage $message
 	 */
-	public function setRepliedMessage(IMessage $message) {
+	public function setInReplyTo(string $message) {
 		throw new Exception('not implemented');
 	}
 
